@@ -94,22 +94,22 @@ set_contents (GtkWidget *area,
 }
 
 static void
-info_bar_add_stock_button_with_text (GtkInfoBar  *info_bar,
-				     const gchar *text,
-				     const gchar *stock_id,
-				     gint         response_id)
+info_bar_add_button_with_text (GtkInfoBar  *info_bar,
+			       const gchar *text,
+			       const gchar *icon_name,
+			       gint         response_id)
 {
 	GtkWidget *button;
 	GtkWidget *image;
 
 	button = gtk_info_bar_add_button (info_bar, text, response_id);
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
+	image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image (GTK_BUTTON (button), image);
 }
 
 static void
 set_info_bar_text_and_icon (GtkWidget   *info_bar,
-			    const gchar *icon_stock_id,
+			    const gchar *icon_name,
 			    const gchar *primary_text,
 			    const gchar *secondary_text)
 {
@@ -123,7 +123,7 @@ set_info_bar_text_and_icon (GtkWidget   *info_bar,
 
 	hbox_content = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
 
-	image = gtk_image_new_from_stock (icon_stock_id, GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
 	gtk_widget_set_valign (image, GTK_ALIGN_START);
 
@@ -172,16 +172,16 @@ create_io_loading_error_info_bar (const gchar *primary_text,
 				       GTK_MESSAGE_ERROR);
 
 	set_info_bar_text_and_icon (info_bar,
-					"gtk-dialog-error",
-					primary_text,
-					secondary_text);
+				    "dialog-error",
+				    primary_text,
+				    secondary_text);
 
 	if (recoverable_error)
 	{
-		info_bar_add_stock_button_with_text (GTK_INFO_BAR (info_bar),
-						     _("_Retry"),
-						     GTK_STOCK_REFRESH,
-						     GTK_RESPONSE_OK);
+		info_bar_add_button_with_text (GTK_INFO_BAR (info_bar),
+					       _("_Retry"),
+					       "view-refresh",
+					       GTK_RESPONSE_OK);
 	}
 
 	return info_bar;
@@ -493,10 +493,10 @@ create_conversion_error_info_bar (const gchar *primary_text,
 
 	info_bar = gtk_info_bar_new ();
 
-	info_bar_add_stock_button_with_text (GTK_INFO_BAR (info_bar),
-					     _("_Retry"),
-					     GTK_STOCK_REDO,
-					     GTK_RESPONSE_OK);
+	info_bar_add_button_with_text (GTK_INFO_BAR (info_bar),
+				       _("_Retry"),
+				       "edit-redo",
+				       GTK_RESPONSE_OK);
 
 	if (edit_anyway)
 	{
@@ -520,7 +520,8 @@ create_conversion_error_info_bar (const gchar *primary_text,
 
 	hbox_content = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
 
-	image = gtk_image_new_from_stock ("gtk-dialog-error", GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name ("dialog-error",
+	                                      GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
 	gtk_widget_set_valign (image, GTK_ALIGN_START);
 
@@ -793,7 +794,8 @@ gedit_file_already_open_warning_info_bar_new (GFile *location)
 
 	hbox_content = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
 
-	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name ("dialog-warning",
+	                                      GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
 	gtk_widget_set_halign (image, GTK_ALIGN_START);
 
@@ -871,9 +873,9 @@ gedit_externally_modified_saving_error_info_bar_new (GFile        *location,
 
 	info_bar = gtk_info_bar_new ();
 
-	info_bar_add_stock_button_with_text (GTK_INFO_BAR (info_bar),
+	info_bar_add_button_with_text (GTK_INFO_BAR (info_bar),
 					     _("S_ave Anyway"),
-					     GTK_STOCK_SAVE,
+					     _("_Save"),
 					     GTK_RESPONSE_YES);
 	gtk_info_bar_add_button (GTK_INFO_BAR (info_bar),
 				 _("D_on't Save"),
@@ -883,7 +885,8 @@ gedit_externally_modified_saving_error_info_bar_new (GFile        *location,
 
 	hbox_content = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
 
-	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name ("dialog-warning",
+	                                      GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
 	gtk_widget_set_valign (image, GTK_ALIGN_START);
 
@@ -969,10 +972,10 @@ gedit_no_backup_saving_error_info_bar_new (GFile        *location,
 
 	info_bar = gtk_info_bar_new ();
 
-	info_bar_add_stock_button_with_text (GTK_INFO_BAR (info_bar),
-					     _("S_ave Anyway"),
-					     GTK_STOCK_SAVE,
-					     GTK_RESPONSE_YES);
+	info_bar_add_button_with_text (GTK_INFO_BAR (info_bar),
+				       _("S_ave Anyway"),
+				       _("_Save"),
+				       GTK_RESPONSE_YES);
 	gtk_info_bar_add_button (GTK_INFO_BAR (info_bar),
 				 _("D_on't Save"),
 				 GTK_RESPONSE_CANCEL);
@@ -981,7 +984,8 @@ gedit_no_backup_saving_error_info_bar_new (GFile        *location,
 
 	hbox_content = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
 
-	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name ("dialog-warning",
+	                                      GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
 	gtk_widget_set_valign (image, GTK_ALIGN_START);
 
@@ -1204,10 +1208,10 @@ gedit_externally_modified_info_bar_new (GFile    *location,
 
 	info_bar = gtk_info_bar_new ();
 
-	info_bar_add_stock_button_with_text (GTK_INFO_BAR (info_bar),
-					     _("_Reload"),
-					     GTK_STOCK_REFRESH,
-					     GTK_RESPONSE_OK);
+	info_bar_add_button_with_text (GTK_INFO_BAR (info_bar),
+				       _("_Reload"),
+				       "view-refresh",
+				       GTK_RESPONSE_OK);
 	gtk_info_bar_add_button (GTK_INFO_BAR (info_bar),
 				 GTK_STOCK_CANCEL,
 				 GTK_RESPONSE_CANCEL);
@@ -1258,10 +1262,10 @@ gedit_invalid_character_info_bar_new (GFile *location)
 
 	info_bar = gtk_info_bar_new ();
 
-	info_bar_add_stock_button_with_text (GTK_INFO_BAR (info_bar),
-					     _("S_ave Anyway"),
-					     GTK_STOCK_SAVE,
-					     GTK_RESPONSE_YES);
+	info_bar_add_button_with_text (GTK_INFO_BAR (info_bar),
+				       _("S_ave Anyway"),
+				       _("_Save"),
+				       GTK_RESPONSE_YES);
 	gtk_info_bar_add_button (GTK_INFO_BAR (info_bar),
 				 _("D_on't Save"),
 				 GTK_RESPONSE_CANCEL);
@@ -1270,7 +1274,8 @@ gedit_invalid_character_info_bar_new (GFile *location)
 
 	hbox_content = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
 
-	image = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name ("dialog-warning",
+	                                      GTK_ICON_SIZE_DIALOG);
 	gtk_box_pack_start (GTK_BOX (hbox_content), image, FALSE, FALSE, 0);
 	gtk_widget_set_valign (image, GTK_ALIGN_START);
 
