@@ -133,9 +133,12 @@ gedit_statusbar_init (GeditStatusbar *statusbar)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_container_add (GTK_CONTAINER (statusbar->priv->state_frame), hbox);
 
-	statusbar->priv->load_image = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
-	statusbar->priv->save_image = gtk_image_new_from_stock (GTK_STOCK_SAVE, GTK_ICON_SIZE_MENU);
-	statusbar->priv->print_image = gtk_image_new_from_stock (GTK_STOCK_PRINT, GTK_ICON_SIZE_MENU);
+	statusbar->priv->load_image = gtk_image_new_from_icon_name ("document-open",
+	                                                            GTK_ICON_SIZE_MENU);
+	statusbar->priv->save_image = gtk_image_new_from_icon_name ("document-save",
+	                                                            GTK_ICON_SIZE_MENU);
+	statusbar->priv->print_image = gtk_image_new_from_icon_name ("document-print",
+	                                                             GTK_ICON_SIZE_MENU);
 
 	gtk_widget_show (hbox);
 
@@ -157,8 +160,8 @@ gedit_statusbar_init (GeditStatusbar *statusbar)
 	gtk_frame_set_shadow_type (GTK_FRAME (statusbar->priv->error_frame),
 				   GTK_SHADOW_IN);
 
-	error_image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_ERROR,
-					        GTK_ICON_SIZE_MENU);
+	error_image = gtk_image_new_from_icon_name ("dialog-error",
+					            GTK_ICON_SIZE_MENU);
 	gtk_misc_set_padding (GTK_MISC (error_image), 4, 0);
 	gtk_widget_show (error_image);
 
