@@ -92,6 +92,7 @@ struct _FileBrowserNode
 	GFile *file;
 	guint flags;
 	gchar *name;
+	gchar *markup;
 
 	GdkPixbuf *icon;
 	GdkPixbuf *emblem;
@@ -105,7 +106,6 @@ struct _FileBrowserNodeDir
 {
 	FileBrowserNode node;
 	GSList *children;
-	GHashTable *hidden_file_hash;
 
 	GCancellable *cancellable;
 	GFileMonitor *monitor;
@@ -491,9 +491,10 @@ gedit_file_browser_store_init (GeditFileBrowserStore *obj)
 	obj->priv = GEDIT_FILE_BROWSER_STORE_GET_PRIVATE (obj);
 
 	obj->priv->column_types[GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION] = G_TYPE_FILE;
-	obj->priv->column_types[GEDIT_FILE_BROWSER_STORE_COLUMN_NAME] = G_TYPE_STRING;
+	obj->priv->column_types[GEDIT_FILE_BROWSER_STORE_COLUMN_MARKUP] = G_TYPE_STRING;
 	obj->priv->column_types[GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS] = G_TYPE_UINT;
 	obj->priv->column_types[GEDIT_FILE_BROWSER_STORE_COLUMN_ICON] = GDK_TYPE_PIXBUF;
+	obj->priv->column_types[GEDIT_FILE_BROWSER_STORE_COLUMN_NAME] = G_TYPE_STRING;
 	obj->priv->column_types[GEDIT_FILE_BROWSER_STORE_COLUMN_EMBLEM] = GDK_TYPE_PIXBUF;
 
 	/* Default filter mode is hiding the hidden files */
@@ -724,8 +725,8 @@ gedit_file_browser_store_get_value (GtkTreeModel *tree_model,
 		case GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION:
 			set_gvalue_from_node (value, node);
 			break;
-		case GEDIT_FILE_BROWSER_STORE_COLUMN_NAME:
-			g_value_set_string (value, node->name);
+		case GEDIT_FILE_BROWSER_STORE_COLUMN_MARKUP:
+			g_value_set_string (value, node->markup);
 			break;
 		case GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS:
 			g_value_set_uint (value, node->flags);
@@ -733,6 +734,9 @@ gedit_file_browser_store_get_value (GtkTreeModel *tree_model,
 		case GEDIT_FILE_BROWSER_STORE_COLUMN_ICON:
 			g_value_set_object (value, node->icon);
 			break;
+		case GEDIT_FILE_BROWSER_STORE_COLUMN_NAME:
+			g_value_set_string (value, node->name);
+			break;
 		case GEDIT_FILE_BROWSER_STORE_COLUMN_EMBLEM:
 			g_value_set_object (value, node->emblem);
 			break;
@@ -1357,11 +1361,17 @@ static void
 file_browser_node_set_name (FileBrowserNode *node)
 {
 	g_free (node->name);
+	g_free (node->markup);
 
 	if (node->file)
 		node->name = gedit_file_browser_utils_file_basename (node->file);
 	else
 		node->name = NULL;
+
+	if (node->name)
+		node->markup = g_markup_escape_text (node->name, -1);
+	else
+		node->markup = NULL;
 }
 
 static void
@@ -1453,9 +1463,6 @@ file_browser_node_free (GeditFileBrowserStore *model,
 			g_file_monitor_cancel (dir->monitor);
 			g_object_unref (dir->monitor);
 		}
-
-		if (dir->hidden_file_hash)
-			g_hash_table_destroy (dir->hidden_file_hash);
 	}
 
 	if (node->file)
@@ -1471,6 +1478,7 @@ file_browser_node_free (GeditFileBrowserStore *model,
 		g_object_unref (node->emblem);
 
 	g_free (node->name);
+	g_free (node->markup);
 
 	if (NODE_IS_DIR (node))
 		g_slice_free (FileBrowserNodeDir, (FileBrowserNodeDir *)node);
@@ -1713,6 +1721,10 @@ model_recomposite_icon_real (GeditFileBrowserStore *tree_model,
 		icon = gedit_file_browser_utils_pixbuf_from_file (node->file, GTK_ICON_SIZE_MENU, FALSE);
 	}
 
+	/* Fallback to the same icon as the file browser */
+	if (!icon)
+		icon = gedit_file_browser_utils_pixbuf_from_theme ("text-x-generic", GTK_ICON_SIZE_MENU);
+
 	if (node->icon)
 		g_object_unref (node->icon);
 
@@ -1769,6 +1781,7 @@ model_create_dummy_node (GeditFileBrowserStore *model,
 
 	dummy = file_browser_node_new (NULL, parent);
 	dummy->name = g_strdup (_("(Empty)"));
+	dummy->markup = g_markup_escape_text (dummy->name, -1);
 
 	dummy->flags |= GEDIT_FILE_BROWSER_STORE_FLAG_IS_DUMMY;
 	dummy->flags |= GEDIT_FILE_BROWSER_STORE_FLAG_IS_HIDDEN;
@@ -2059,9 +2072,7 @@ file_browser_node_set_from_info (GeditFileBrowserStore *model,
 				 GFileInfo             *info,
 				 gboolean               isadded)
 {
-	FileBrowserNodeDir *dir;
 	gchar const *content;
-	gchar const *name;
 	gboolean free_info = FALSE;
 	GtkTreePath *path;
 	gchar *uri;
@@ -2091,18 +2102,10 @@ file_browser_node_set_from_info (GeditFileBrowserStore *model,
 		free_info = TRUE;
 	}
 
-	dir = FILE_BROWSER_NODE_DIR (node->parent);
-	name = g_file_info_get_name (info);
-
 	if (g_file_info_get_is_hidden (info) || g_file_info_get_is_backup (info))
 	{
 		node->flags |= GEDIT_FILE_BROWSER_STORE_FLAG_IS_HIDDEN;
 	}
-	else if (dir != NULL && dir->hidden_file_hash != NULL &&
-		 g_hash_table_lookup (dir->hidden_file_hash, name) != NULL)
-	{
-		node->flags |= GEDIT_FILE_BROWSER_STORE_FLAG_IS_HIDDEN;
-	}
 
 	if (g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY)
 	{
@@ -2300,79 +2303,6 @@ model_add_node_from_dir (GeditFileBrowserStore *model,
 	return node;
 }
 
-/* Read is sync, but we only do it for local files */
-static void
-parse_dot_hidden_file (FileBrowserNode *directory)
-{
-	gsize file_size;
-	char *file_contents;
-	GFile *child;
-	GFileInfo *info;
-	GFileType type;
-	int i;
-	FileBrowserNodeDir *dir = FILE_BROWSER_NODE_DIR (directory);
-
-	/* FIXME: We only support .hidden on file: uri's for the moment.
-	 * Need to figure out if we should do this async or sync to extend
-	 * it to all types of uris.
-	 */
-	if (directory->file == NULL || !g_file_is_native (directory->file))
-		return;
-
-	child = g_file_get_child (directory->file, ".hidden");
-	info = g_file_query_info (child, G_FILE_ATTRIBUTE_STANDARD_TYPE, G_FILE_QUERY_INFO_NONE, NULL, NULL);
-
-	type = info ? g_file_info_get_file_type (info) : G_FILE_TYPE_UNKNOWN;
-
-	if (info)
-		g_object_unref (info);
-
-	if (type != G_FILE_TYPE_REGULAR)
-	{
-		g_object_unref (child);
-		return;
-	}
-
-	if (!g_file_load_contents (child, NULL, &file_contents, &file_size, NULL, NULL))
-	{
-		g_object_unref (child);
-		return;
-	}
-
-	g_object_unref (child);
-
-	if (dir->hidden_file_hash == NULL)
-	{
-		dir->hidden_file_hash =
-			g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
-	}
-
-	/* Now parse the data */
-	i = 0;
-	while (i < file_size)
-	{
-		int start;
-
-		start = i;
-		while (i < file_size && file_contents[i] != '\n')
-			i++;
-
-		if (i > start)
-		{
-			char *hidden_filename;
-
-			hidden_filename = g_strndup (file_contents + start, i - start);
-			g_hash_table_insert (dir->hidden_file_hash,
-					     hidden_filename, hidden_filename);
-		}
-
-		i++;
-
-	}
-
-	g_free (file_contents);
-}
-
 static void
 on_directory_monitor_event (GFileMonitor      *monitor,
 			    GFile             *file,
@@ -2558,9 +2488,6 @@ model_load_directory (GeditFileBrowserStore *model,
 	node->flags |= GEDIT_FILE_BROWSER_STORE_FLAG_LOADED;
 	model_begin_loading (model, node);
 
-	/* Read the '.hidden' file first (if any) */
-	parse_dot_hidden_file (node);
-
 	dir->cancellable = g_cancellable_new ();
 
 	async = g_slice_new (AsyncNode);
@@ -3033,27 +2960,46 @@ gedit_file_browser_store_set_value (GeditFileBrowserStore *tree_model,
 	GtkTreePath *path;
 
 	g_return_if_fail (GEDIT_IS_FILE_BROWSER_STORE (tree_model));
-	g_return_if_fail (column == GEDIT_FILE_BROWSER_STORE_COLUMN_EMBLEM);
-	g_return_if_fail (G_VALUE_HOLDS_OBJECT (value));
 	g_return_if_fail (iter != NULL);
 	g_return_if_fail (iter->user_data != NULL);
 
-	data = g_value_get_object (value);
-
-	if (data)
-		g_return_if_fail (GDK_IS_PIXBUF (data));
-
 	node = (FileBrowserNode *) (iter->user_data);
 
-	if (node->emblem)
-		g_object_unref (node->emblem);
+	if (column == GEDIT_FILE_BROWSER_STORE_COLUMN_MARKUP)
+	{
+		g_return_if_fail (G_VALUE_HOLDS_STRING (value));
 
-	if (data)
-		node->emblem = g_object_ref (GDK_PIXBUF (data));
+		data = g_value_dup_string (value);
+
+		if (!data)
+			data = g_strdup (node->name);
+
+		g_free (node->markup);
+		node->markup = g_strdup (data);
+	}
+	else if (column == GEDIT_FILE_BROWSER_STORE_COLUMN_EMBLEM)
+	{
+		g_return_if_fail (G_VALUE_HOLDS_OBJECT (value));
+
+		data = g_value_get_object (value);
+
+		g_return_if_fail (GDK_IS_PIXBUF (data) || data == NULL);
+
+		if (node->emblem)
+			g_object_unref (node->emblem);
+
+		if (data)
+			node->emblem = g_object_ref (GDK_PIXBUF (data));
+		else
+			node->emblem = NULL;
+
+		model_recomposite_icon (tree_model, iter);
+	}
 	else
-		node->emblem = NULL;
-
-	model_recomposite_icon (tree_model, iter);
+	{
+		g_return_if_fail (column == GEDIT_FILE_BROWSER_STORE_COLUMN_MARKUP ||
+		                  column == GEDIT_FILE_BROWSER_STORE_COLUMN_EMBLEM);
+	}
 
 	if (model_node_visibility (tree_model, node))
 	{
